@@ -445,7 +445,7 @@ def _jwst_s2d_loader(filename, **kwargs):
     slits = None
 
     # Get a list of GWCS objects from the slits
-    with asdf_in_fits.open(filename) as af:
+    with fits.open(filename, memmap=False) as hdulist, asdf_in_fits.open(hdulist) as af:
         # Slits can be listed under "slits", "products" or "exposures"
         if "products" in af.tree:
             slits = "products"
@@ -461,8 +461,6 @@ def _jwst_s2d_loader(filename, **kwargs):
         if slits is not None:
             wcslist = [slit["meta"]["wcs"] for slit in af.tree[slits]]
 
-    with fits.open(filename, memmap=False) as hdulist:
-
         primary_header = hdulist["PRIMARY"].header
 
         hdulist_sci = [hdu for hdu in hdulist if hdu.name == "SCI"]
@@ -567,11 +565,9 @@ def _jwst_s3d_loader(filename, **kwargs):
     spectra = []
 
     # Get a list of GWCS objects from the slits
-    with asdf_in_fits.open(filename) as af:
+    with fits.open(filename, memmap=False) as hdulist, asdf_in_fits.open(hdulist) as af:
         wcslist = [af.tree["meta"]["wcs"]]
 
-    with fits.open(filename, memmap=False) as hdulist:
-
         primary_header = hdulist["PRIMARY"].header
 
         hdulist_sci = [hdu for hdu in hdulist if hdu.name == "SCI"]
